@@ -8,6 +8,7 @@ package net.mediaarea.mediainfo
 
 import android.app.Application
 import androidx.appcompat.app.AppCompatDelegate
+import com.google.android.material.color.DynamicColors
 
 import com.yariksoffice.lingver.Lingver
 import com.yariksoffice.lingver.store.InMemoryLocaleStore
@@ -15,9 +16,17 @@ import com.yariksoffice.lingver.store.InMemoryLocaleStore
 
 class MediaInfoApplication : Application() {
     override fun onCreate() {
+        DynamicColors.applyToActivitiesIfAvailable(this)
+
         super.onCreate()
 
         Lingver.init(this, InMemoryLocaleStore())
         AppCompatDelegate.setDefaultNightMode(AppCompatDelegate.MODE_NIGHT_NO)
     }
+
+    override fun onTerminate() {
+        SubscriptionManager.getInstance(this).terminate()
+
+        super.onTerminate()
+    }
 }
\ No newline at end of file
