@@ -10,6 +10,7 @@
 #include <QBoxLayout>
 #include <QComboBox>
 
+#include <memory>
 #include <ZenLib/Ztring.h>
 using namespace ZenLib;
 #define wstring2QString(_DATA) \
@@ -35,7 +36,7 @@ void EasyViewWidget::refreshDisplay() {
         delete this->layout();
     }
 
-    QVBoxLayout *layout = new QVBoxLayout;
+    QVBoxLayout *layout = new QVBoxLayout();
     setLayout(layout);
 
     QComboBox* fileChoice = new QComboBox();
@@ -54,25 +55,21 @@ void EasyViewWidget::refreshDisplay() {
 
     connect(fileChoice,SIGNAL(currentIndexChanged(int)),SLOT(changeFilePos(int)));
 
-    QFrame *box;
-    QGroupBox *subBox;
     for (size_t StreamPos=0; StreamPos<Stream_Max; StreamPos++) {
         bool addBox = false;
-        box = new QFrame();
-        QHBoxLayout* boxLayout = new QHBoxLayout();
-        box->setLayout(boxLayout);
+        std::unique_ptr<QFrame> box(new QFrame());
+        QHBoxLayout* boxLayout{ new QHBoxLayout(box.get()) };
         for (size_t Pos=0; Pos<Boxes_Count_Get(StreamPos); Pos++) {
-            subBox = createBox((stream_t)StreamPos,(int)Pos);
+            QGroupBox* subBox = createBox((stream_t)StreamPos,(int)Pos);
             if(subBox!=NULL) {
                 boxLayout->addWidget(subBox);
                 addBox = true;
             }
         }
         if(addBox) {
-            layout->addWidget(box);
-            Boxes.push_back(box);
+            layout->addWidget(box.get());
+            Boxes.push_back(box.release());
         }
-
     }
     layout->addStretch();
 }
